# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEndpointsArgs',
    'InstanceEndpointsArgsDict',
    'InstanceEndpointsOverlayArgs',
    'InstanceEndpointsOverlayArgsDict',
    'InstanceEndpointsPublicArgs',
    'InstanceEndpointsPublicArgsDict',
    'InstanceResourceTagArgs',
    'InstanceResourceTagArgsDict',
    'InstanceResourceTagTagKvArgs',
    'InstanceResourceTagTagKvArgsDict',
    'InstanceResourcesArgs',
    'InstanceResourcesArgsDict',
    'InstanceResourcesStorageArgs',
    'InstanceResourcesStorageArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceEndpointsArgsDict(TypedDict):
        overlay: NotRequired[pulumi.Input['InstanceEndpointsOverlayArgsDict']]
        """
        实例私网访问接入点响应数据。
        """
        public: NotRequired[pulumi.Input['InstanceEndpointsPublicArgsDict']]
        """
        实例公网访问接入点响应数据。
        """
elif False:
    InstanceEndpointsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsArgs:
    def __init__(__self__, *,
                 overlay: Optional[pulumi.Input['InstanceEndpointsOverlayArgs']] = None,
                 public: Optional[pulumi.Input['InstanceEndpointsPublicArgs']] = None):
        """
        :param pulumi.Input['InstanceEndpointsOverlayArgs'] overlay: 实例私网访问接入点响应数据。
        :param pulumi.Input['InstanceEndpointsPublicArgs'] public: 实例公网访问接入点响应数据。
        """
        if overlay is not None:
            pulumi.set(__self__, "overlay", overlay)
        if public is not None:
            pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter
    def overlay(self) -> Optional[pulumi.Input['InstanceEndpointsOverlayArgs']]:
        """
        实例私网访问接入点响应数据。
        """
        return pulumi.get(self, "overlay")

    @overlay.setter
    def overlay(self, value: Optional[pulumi.Input['InstanceEndpointsOverlayArgs']]):
        pulumi.set(self, "overlay", value)

    @property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input['InstanceEndpointsPublicArgs']]:
        """
        实例公网访问接入点响应数据。
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input['InstanceEndpointsPublicArgs']]):
        pulumi.set(self, "public", value)


if not MYPY:
    class InstanceEndpointsOverlayArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        域名映射地址。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例绑定的EIP的ID。
        """
        plain: NotRequired[pulumi.Input[builtins.str]]
        """
        私网Plain接入点。
        """
        plain_port: NotRequired[pulumi.Input[builtins.int]]
        """
        普通接入点端口。
        """
        sasl: NotRequired[pulumi.Input[builtins.str]]
        """
        私网SASL认证接入点。
        """
        sasl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        认证接入点端口。
        """
        ssl: NotRequired[pulumi.Input[builtins.str]]
        """
        加密接入点。
        """
        ssl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        加密接入点端口。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点状态。
        """
        vpc_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        售卖区网络关联的VPC ID列表。
        """
elif False:
    InstanceEndpointsOverlayArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsOverlayArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 plain: Optional[pulumi.Input[builtins.str]] = None,
                 plain_port: Optional[pulumi.Input[builtins.int]] = None,
                 sasl: Optional[pulumi.Input[builtins.str]] = None,
                 sasl_port: Optional[pulumi.Input[builtins.int]] = None,
                 ssl: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_port: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.str] address: 域名映射地址。
        :param pulumi.Input[builtins.str] eip_id: 实例绑定的EIP的ID。
        :param pulumi.Input[builtins.str] plain: 私网Plain接入点。
        :param pulumi.Input[builtins.int] plain_port: 普通接入点端口。
        :param pulumi.Input[builtins.str] sasl: 私网SASL认证接入点。
        :param pulumi.Input[builtins.int] sasl_port: 认证接入点端口。
        :param pulumi.Input[builtins.str] ssl: 加密接入点。
        :param pulumi.Input[builtins.int] ssl_port: 加密接入点端口。
        :param pulumi.Input[builtins.str] status: 接入点状态。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def plain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @plain.setter
    def plain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plain", value)

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @plain_port.setter
    def plain_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "plain_port", value)

    @property
    @pulumi.getter
    def sasl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @sasl.setter
    def sasl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sasl", value)

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @sasl_port.setter
    def sasl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "sasl_port", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @ssl_port.setter
    def ssl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_port", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")

    @vpc_ids.setter
    def vpc_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpc_ids", value)


if not MYPY:
    class InstanceEndpointsPublicArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        域名映射地址。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例绑定的EIP的ID。
        """
        plain: NotRequired[pulumi.Input[builtins.str]]
        """
        私网Plain接入点。
        """
        plain_port: NotRequired[pulumi.Input[builtins.int]]
        """
        普通接入点端口。
        """
        sasl: NotRequired[pulumi.Input[builtins.str]]
        """
        私网SASL认证接入点。
        """
        sasl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        认证接入点端口。
        """
        ssl: NotRequired[pulumi.Input[builtins.str]]
        """
        加密接入点。
        """
        ssl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        加密接入点端口。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点状态。
        """
        vpc_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        售卖区网络关联的VPC ID列表。
        """
elif False:
    InstanceEndpointsPublicArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsPublicArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 plain: Optional[pulumi.Input[builtins.str]] = None,
                 plain_port: Optional[pulumi.Input[builtins.int]] = None,
                 sasl: Optional[pulumi.Input[builtins.str]] = None,
                 sasl_port: Optional[pulumi.Input[builtins.int]] = None,
                 ssl: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_port: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.str] address: 域名映射地址。
        :param pulumi.Input[builtins.str] eip_id: 实例绑定的EIP的ID。
        :param pulumi.Input[builtins.str] plain: 私网Plain接入点。
        :param pulumi.Input[builtins.int] plain_port: 普通接入点端口。
        :param pulumi.Input[builtins.str] sasl: 私网SASL认证接入点。
        :param pulumi.Input[builtins.int] sasl_port: 认证接入点端口。
        :param pulumi.Input[builtins.str] ssl: 加密接入点。
        :param pulumi.Input[builtins.int] ssl_port: 加密接入点端口。
        :param pulumi.Input[builtins.str] status: 接入点状态。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def plain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @plain.setter
    def plain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plain", value)

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @plain_port.setter
    def plain_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "plain_port", value)

    @property
    @pulumi.getter
    def sasl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @sasl.setter
    def sasl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sasl", value)

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @sasl_port.setter
    def sasl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "sasl_port", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @ssl_port.setter
    def ssl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_port", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")

    @vpc_ids.setter
    def vpc_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpc_ids", value)


if not MYPY:
    class InstanceResourceTagArgsDict(TypedDict):
        tag_kvs: NotRequired[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgsDict']]]]
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
elif False:
    InstanceResourceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourceTagArgs:
    def __init__(__self__, *,
                 tag_kvs: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] type: 标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        if tag_kvs is not None:
            pulumi.set(__self__, "tag_kvs", tag_kvs)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="tagKvs")
    def tag_kvs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]]:
        return pulumi.get(self, "tag_kvs")

    @tag_kvs.setter
    def tag_kvs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]]):
        pulumi.set(self, "tag_kvs", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class InstanceResourceTagTagKvArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceResourceTagTagKvArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourceTagTagKvArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class InstanceResourcesArgsDict(TypedDict):
        storage: NotRequired[pulumi.Input['InstanceResourcesStorageArgsDict']]
        """
        资源统计响应数据。
        """
elif False:
    InstanceResourcesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourcesArgs:
    def __init__(__self__, *,
                 storage: Optional[pulumi.Input['InstanceResourcesStorageArgs']] = None):
        """
        :param pulumi.Input['InstanceResourcesStorageArgs'] storage: 资源统计响应数据。
        """
        if storage is not None:
            pulumi.set(__self__, "storage", storage)

    @property
    @pulumi.getter
    def storage(self) -> Optional[pulumi.Input['InstanceResourcesStorageArgs']]:
        """
        资源统计响应数据。
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: Optional[pulumi.Input['InstanceResourcesStorageArgs']]):
        pulumi.set(self, "storage", value)


if not MYPY:
    class InstanceResourcesStorageArgsDict(TypedDict):
        size: NotRequired[pulumi.Input[builtins.int]]
        """
        资源大小。
        """
        unit: NotRequired[pulumi.Input[builtins.str]]
        """
        资源单位。
        """
elif False:
    InstanceResourcesStorageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourcesStorageArgs:
    def __init__(__self__, *,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 unit: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] size: 资源大小。
        :param pulumi.Input[builtins.str] unit: 资源单位。
        """
        if size is not None:
            pulumi.set(__self__, "size", size)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        资源大小。
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源单位。
        """
        return pulumi.get(self, "unit")

    @unit.setter
    def unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "unit", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRoleResult',
    'AwaitableGetRoleResult',
    'get_role',
    'get_role_output',
]

@pulumi.output_type
class GetRoleResult:
    """
    A collection of values returned by getRole.
    """
    def __init__(__self__, create_date=None, description=None, display_name=None, id=None, is_service_linked_role=None, max_session_duration=None, policies=None, role_id=None, role_name=None, tags=None, trn=None, trust_policy_document=None, update_date=None):
        if create_date and not isinstance(create_date, str):
            raise TypeError("Expected argument 'create_date' to be a str")
        pulumi.set(__self__, "create_date", create_date)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_service_linked_role and not isinstance(is_service_linked_role, int):
            raise TypeError("Expected argument 'is_service_linked_role' to be a int")
        pulumi.set(__self__, "is_service_linked_role", is_service_linked_role)
        if max_session_duration and not isinstance(max_session_duration, int):
            raise TypeError("Expected argument 'max_session_duration' to be a int")
        pulumi.set(__self__, "max_session_duration", max_session_duration)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if role_id and not isinstance(role_id, int):
            raise TypeError("Expected argument 'role_id' to be a int")
        pulumi.set(__self__, "role_id", role_id)
        if role_name and not isinstance(role_name, str):
            raise TypeError("Expected argument 'role_name' to be a str")
        pulumi.set(__self__, "role_name", role_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if trn and not isinstance(trn, str):
            raise TypeError("Expected argument 'trn' to be a str")
        pulumi.set(__self__, "trn", trn)
        if trust_policy_document and not isinstance(trust_policy_document, str):
            raise TypeError("Expected argument 'trust_policy_document' to be a str")
        pulumi.set(__self__, "trust_policy_document", trust_policy_document)
        if update_date and not isinstance(update_date, str):
            raise TypeError("Expected argument 'update_date' to be a str")
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        角色创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        角色描述，长度不超过128。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        角色显示名，长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isServiceLinkedRole")
    def is_service_linked_role(self) -> builtins.int:
        """
        是否是服务关联角色, 0否，1是。
        """
        return pulumi.get(self, "is_service_linked_role")

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> builtins.int:
        """
        角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        """
        return pulumi.get(self, "max_session_duration")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetRolePolicyResult']:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> builtins.int:
        """
        角色ID。
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> builtins.str:
        """
        角色名，长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetRoleTagResult']:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        角色TRN。
        """
        return pulumi.get(self, "trn")

    @property
    @pulumi.getter(name="trustPolicyDocument")
    def trust_policy_document(self) -> builtins.str:
        """
        角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        return pulumi.get(self, "trust_policy_document")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        角色更新时间。
        """
        return pulumi.get(self, "update_date")


class AwaitableGetRoleResult(GetRoleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleResult(
            create_date=self.create_date,
            description=self.description,
            display_name=self.display_name,
            id=self.id,
            is_service_linked_role=self.is_service_linked_role,
            max_session_duration=self.max_session_duration,
            policies=self.policies,
            role_id=self.role_id,
            role_name=self.role_name,
            tags=self.tags,
            trn=self.trn,
            trust_policy_document=self.trust_policy_document,
            update_date=self.update_date)


def get_role(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoleResult:
    """
    Data Source schema for Byteplus::IAM::Role


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:iam/getRole:getRole', __args__, opts=opts, typ=GetRoleResult).value

    return AwaitableGetRoleResult(
        create_date=pulumi.get(__ret__, 'create_date'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        is_service_linked_role=pulumi.get(__ret__, 'is_service_linked_role'),
        max_session_duration=pulumi.get(__ret__, 'max_session_duration'),
        policies=pulumi.get(__ret__, 'policies'),
        role_id=pulumi.get(__ret__, 'role_id'),
        role_name=pulumi.get(__ret__, 'role_name'),
        tags=pulumi.get(__ret__, 'tags'),
        trn=pulumi.get(__ret__, 'trn'),
        trust_policy_document=pulumi.get(__ret__, 'trust_policy_document'),
        update_date=pulumi.get(__ret__, 'update_date'))
def get_role_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRoleResult]:
    """
    Data Source schema for Byteplus::IAM::Role


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:iam/getRole:getRole', __args__, opts=opts, typ=GetRoleResult)
    return __ret__.apply(lambda __response__: GetRoleResult(
        create_date=pulumi.get(__response__, 'create_date'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        is_service_linked_role=pulumi.get(__response__, 'is_service_linked_role'),
        max_session_duration=pulumi.get(__response__, 'max_session_duration'),
        policies=pulumi.get(__response__, 'policies'),
        role_id=pulumi.get(__response__, 'role_id'),
        role_name=pulumi.get(__response__, 'role_name'),
        tags=pulumi.get(__response__, 'tags'),
        trn=pulumi.get(__response__, 'trn'),
        trust_policy_document=pulumi.get(__response__, 'trust_policy_document'),
        update_date=pulumi.get(__response__, 'update_date')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'KeyMultiRegionConfigurationArgs',
    'KeyMultiRegionConfigurationArgsDict',
    'KeyMultiRegionConfigurationPrimaryKeyArgs',
    'KeyMultiRegionConfigurationPrimaryKeyArgsDict',
    'KeyMultiRegionConfigurationReplicaKeyArgs',
    'KeyMultiRegionConfigurationReplicaKeyArgsDict',
    'KeyTagArgs',
    'KeyTagArgsDict',
]

MYPY = False

if not MYPY:
    class KeyMultiRegionConfigurationArgsDict(TypedDict):
        multi_region_key_type: NotRequired[pulumi.Input[builtins.str]]
        """
        多区域密钥的类型。
        """
        primary_key: NotRequired[pulumi.Input['KeyMultiRegionConfigurationPrimaryKeyArgsDict']]
        """
        主多区域键的事务识别号和区域 ID。
        """
        replica_keys: NotRequired[pulumi.Input[Sequence[pulumi.Input['KeyMultiRegionConfigurationReplicaKeyArgsDict']]]]
elif False:
    KeyMultiRegionConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyMultiRegionConfigurationArgs:
    def __init__(__self__, *,
                 multi_region_key_type: Optional[pulumi.Input[builtins.str]] = None,
                 primary_key: Optional[pulumi.Input['KeyMultiRegionConfigurationPrimaryKeyArgs']] = None,
                 replica_keys: Optional[pulumi.Input[Sequence[pulumi.Input['KeyMultiRegionConfigurationReplicaKeyArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] multi_region_key_type: 多区域密钥的类型。
        :param pulumi.Input['KeyMultiRegionConfigurationPrimaryKeyArgs'] primary_key: 主多区域键的事务识别号和区域 ID。
        """
        if multi_region_key_type is not None:
            pulumi.set(__self__, "multi_region_key_type", multi_region_key_type)
        if primary_key is not None:
            pulumi.set(__self__, "primary_key", primary_key)
        if replica_keys is not None:
            pulumi.set(__self__, "replica_keys", replica_keys)

    @property
    @pulumi.getter(name="multiRegionKeyType")
    def multi_region_key_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多区域密钥的类型。
        """
        return pulumi.get(self, "multi_region_key_type")

    @multi_region_key_type.setter
    def multi_region_key_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_region_key_type", value)

    @property
    @pulumi.getter(name="primaryKey")
    def primary_key(self) -> Optional[pulumi.Input['KeyMultiRegionConfigurationPrimaryKeyArgs']]:
        """
        主多区域键的事务识别号和区域 ID。
        """
        return pulumi.get(self, "primary_key")

    @primary_key.setter
    def primary_key(self, value: Optional[pulumi.Input['KeyMultiRegionConfigurationPrimaryKeyArgs']]):
        pulumi.set(self, "primary_key", value)

    @property
    @pulumi.getter(name="replicaKeys")
    def replica_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KeyMultiRegionConfigurationReplicaKeyArgs']]]]:
        return pulumi.get(self, "replica_keys")

    @replica_keys.setter
    def replica_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KeyMultiRegionConfigurationReplicaKeyArgs']]]]):
        pulumi.set(self, "replica_keys", value)


if not MYPY:
    class KeyMultiRegionConfigurationPrimaryKeyArgsDict(TypedDict):
        region: NotRequired[pulumi.Input[builtins.str]]
        """
        多区域密钥的区域 ID。
        """
        trn: NotRequired[pulumi.Input[builtins.str]]
        """
        多区域密钥的 TRN。
        """
elif False:
    KeyMultiRegionConfigurationPrimaryKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyMultiRegionConfigurationPrimaryKeyArgs:
    def __init__(__self__, *,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 trn: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] region: 多区域密钥的区域 ID。
        :param pulumi.Input[builtins.str] trn: 多区域密钥的 TRN。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter
    def trn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多区域密钥的 TRN。
        """
        return pulumi.get(self, "trn")

    @trn.setter
    def trn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trn", value)


if not MYPY:
    class KeyMultiRegionConfigurationReplicaKeyArgsDict(TypedDict):
        region: NotRequired[pulumi.Input[builtins.str]]
        """
        多区域密钥的区域 ID。
        """
        trn: NotRequired[pulumi.Input[builtins.str]]
        """
        多区域密钥的转换。
        """
elif False:
    KeyMultiRegionConfigurationReplicaKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyMultiRegionConfigurationReplicaKeyArgs:
    def __init__(__self__, *,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 trn: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] region: 多区域密钥的区域 ID。
        :param pulumi.Input[builtins.str] trn: 多区域密钥的转换。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter
    def trn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多区域密钥的转换。
        """
        return pulumi.get(self, "trn")

    @trn.setter
    def trn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trn", value)


if not MYPY:
    class KeyTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        KMS密钥的标签键
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        KMS密钥的标签值
        """
elif False:
    KeyTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: KMS密钥的标签键
        :param pulumi.Input[builtins.str] value: KMS密钥的标签值
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        KMS密钥的标签键
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        KMS密钥的标签值
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, cerebro_enabled=None, cerebro_private_domain=None, cerebro_public_domain=None, charge_enabled=None, cluster_id=None, create_time=None, enable_es_private_domain_public=None, enable_es_private_network=None, enable_es_public_network=None, enable_kibana_private_domain_public=None, enable_kibana_private_network=None, enable_kibana_public_network=None, es_eip=None, es_eip_id=None, es_private_endpoint=None, es_private_ip_allow_list=None, es_private_ip_whitelist=None, es_pub_bandwidth=None, es_public_endpoint=None, es_public_ip_allow_list=None, es_public_ip_whitelist=None, expire_date=None, id=None, instance_configuration=None, instance_id=None, kibana_config=None, kibana_eip=None, kibana_eip_id=None, kibana_private_domain=None, kibana_private_ip_allow_list=None, kibana_private_ip_whitelist=None, kibana_pub_bandwidth=None, kibana_public_domain=None, kibana_public_ip_allow_list=None, kibana_public_ip_whitelist=None, main_zone_id=None, maintenance_days=None, maintenance_time=None, status=None, sub_instance_enable=None, sub_instances=None, support_cold_node=None, total_nodes=None, transfer_info=None, user_id=None):
        if cerebro_enabled and not isinstance(cerebro_enabled, bool):
            raise TypeError("Expected argument 'cerebro_enabled' to be a bool")
        pulumi.set(__self__, "cerebro_enabled", cerebro_enabled)
        if cerebro_private_domain and not isinstance(cerebro_private_domain, str):
            raise TypeError("Expected argument 'cerebro_private_domain' to be a str")
        pulumi.set(__self__, "cerebro_private_domain", cerebro_private_domain)
        if cerebro_public_domain and not isinstance(cerebro_public_domain, str):
            raise TypeError("Expected argument 'cerebro_public_domain' to be a str")
        pulumi.set(__self__, "cerebro_public_domain", cerebro_public_domain)
        if charge_enabled and not isinstance(charge_enabled, bool):
            raise TypeError("Expected argument 'charge_enabled' to be a bool")
        pulumi.set(__self__, "charge_enabled", charge_enabled)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if enable_es_private_domain_public and not isinstance(enable_es_private_domain_public, bool):
            raise TypeError("Expected argument 'enable_es_private_domain_public' to be a bool")
        pulumi.set(__self__, "enable_es_private_domain_public", enable_es_private_domain_public)
        if enable_es_private_network and not isinstance(enable_es_private_network, bool):
            raise TypeError("Expected argument 'enable_es_private_network' to be a bool")
        pulumi.set(__self__, "enable_es_private_network", enable_es_private_network)
        if enable_es_public_network and not isinstance(enable_es_public_network, bool):
            raise TypeError("Expected argument 'enable_es_public_network' to be a bool")
        pulumi.set(__self__, "enable_es_public_network", enable_es_public_network)
        if enable_kibana_private_domain_public and not isinstance(enable_kibana_private_domain_public, bool):
            raise TypeError("Expected argument 'enable_kibana_private_domain_public' to be a bool")
        pulumi.set(__self__, "enable_kibana_private_domain_public", enable_kibana_private_domain_public)
        if enable_kibana_private_network and not isinstance(enable_kibana_private_network, bool):
            raise TypeError("Expected argument 'enable_kibana_private_network' to be a bool")
        pulumi.set(__self__, "enable_kibana_private_network", enable_kibana_private_network)
        if enable_kibana_public_network and not isinstance(enable_kibana_public_network, bool):
            raise TypeError("Expected argument 'enable_kibana_public_network' to be a bool")
        pulumi.set(__self__, "enable_kibana_public_network", enable_kibana_public_network)
        if es_eip and not isinstance(es_eip, str):
            raise TypeError("Expected argument 'es_eip' to be a str")
        pulumi.set(__self__, "es_eip", es_eip)
        if es_eip_id and not isinstance(es_eip_id, str):
            raise TypeError("Expected argument 'es_eip_id' to be a str")
        pulumi.set(__self__, "es_eip_id", es_eip_id)
        if es_private_endpoint and not isinstance(es_private_endpoint, str):
            raise TypeError("Expected argument 'es_private_endpoint' to be a str")
        pulumi.set(__self__, "es_private_endpoint", es_private_endpoint)
        if es_private_ip_allow_list and not isinstance(es_private_ip_allow_list, str):
            raise TypeError("Expected argument 'es_private_ip_allow_list' to be a str")
        pulumi.set(__self__, "es_private_ip_allow_list", es_private_ip_allow_list)
        if es_private_ip_whitelist and not isinstance(es_private_ip_whitelist, str):
            raise TypeError("Expected argument 'es_private_ip_whitelist' to be a str")
        pulumi.set(__self__, "es_private_ip_whitelist", es_private_ip_whitelist)
        if es_pub_bandwidth and not isinstance(es_pub_bandwidth, int):
            raise TypeError("Expected argument 'es_pub_bandwidth' to be a int")
        pulumi.set(__self__, "es_pub_bandwidth", es_pub_bandwidth)
        if es_public_endpoint and not isinstance(es_public_endpoint, str):
            raise TypeError("Expected argument 'es_public_endpoint' to be a str")
        pulumi.set(__self__, "es_public_endpoint", es_public_endpoint)
        if es_public_ip_allow_list and not isinstance(es_public_ip_allow_list, str):
            raise TypeError("Expected argument 'es_public_ip_allow_list' to be a str")
        pulumi.set(__self__, "es_public_ip_allow_list", es_public_ip_allow_list)
        if es_public_ip_whitelist and not isinstance(es_public_ip_whitelist, str):
            raise TypeError("Expected argument 'es_public_ip_whitelist' to be a str")
        pulumi.set(__self__, "es_public_ip_whitelist", es_public_ip_whitelist)
        if expire_date and not isinstance(expire_date, str):
            raise TypeError("Expected argument 'expire_date' to be a str")
        pulumi.set(__self__, "expire_date", expire_date)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_configuration and not isinstance(instance_configuration, dict):
            raise TypeError("Expected argument 'instance_configuration' to be a dict")
        pulumi.set(__self__, "instance_configuration", instance_configuration)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if kibana_config and not isinstance(kibana_config, dict):
            raise TypeError("Expected argument 'kibana_config' to be a dict")
        pulumi.set(__self__, "kibana_config", kibana_config)
        if kibana_eip and not isinstance(kibana_eip, str):
            raise TypeError("Expected argument 'kibana_eip' to be a str")
        pulumi.set(__self__, "kibana_eip", kibana_eip)
        if kibana_eip_id and not isinstance(kibana_eip_id, str):
            raise TypeError("Expected argument 'kibana_eip_id' to be a str")
        pulumi.set(__self__, "kibana_eip_id", kibana_eip_id)
        if kibana_private_domain and not isinstance(kibana_private_domain, str):
            raise TypeError("Expected argument 'kibana_private_domain' to be a str")
        pulumi.set(__self__, "kibana_private_domain", kibana_private_domain)
        if kibana_private_ip_allow_list and not isinstance(kibana_private_ip_allow_list, str):
            raise TypeError("Expected argument 'kibana_private_ip_allow_list' to be a str")
        pulumi.set(__self__, "kibana_private_ip_allow_list", kibana_private_ip_allow_list)
        if kibana_private_ip_whitelist and not isinstance(kibana_private_ip_whitelist, str):
            raise TypeError("Expected argument 'kibana_private_ip_whitelist' to be a str")
        pulumi.set(__self__, "kibana_private_ip_whitelist", kibana_private_ip_whitelist)
        if kibana_pub_bandwidth and not isinstance(kibana_pub_bandwidth, int):
            raise TypeError("Expected argument 'kibana_pub_bandwidth' to be a int")
        pulumi.set(__self__, "kibana_pub_bandwidth", kibana_pub_bandwidth)
        if kibana_public_domain and not isinstance(kibana_public_domain, str):
            raise TypeError("Expected argument 'kibana_public_domain' to be a str")
        pulumi.set(__self__, "kibana_public_domain", kibana_public_domain)
        if kibana_public_ip_allow_list and not isinstance(kibana_public_ip_allow_list, str):
            raise TypeError("Expected argument 'kibana_public_ip_allow_list' to be a str")
        pulumi.set(__self__, "kibana_public_ip_allow_list", kibana_public_ip_allow_list)
        if kibana_public_ip_whitelist and not isinstance(kibana_public_ip_whitelist, str):
            raise TypeError("Expected argument 'kibana_public_ip_whitelist' to be a str")
        pulumi.set(__self__, "kibana_public_ip_whitelist", kibana_public_ip_whitelist)
        if main_zone_id and not isinstance(main_zone_id, str):
            raise TypeError("Expected argument 'main_zone_id' to be a str")
        pulumi.set(__self__, "main_zone_id", main_zone_id)
        if maintenance_days and not isinstance(maintenance_days, list):
            raise TypeError("Expected argument 'maintenance_days' to be a list")
        pulumi.set(__self__, "maintenance_days", maintenance_days)
        if maintenance_time and not isinstance(maintenance_time, str):
            raise TypeError("Expected argument 'maintenance_time' to be a str")
        pulumi.set(__self__, "maintenance_time", maintenance_time)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if sub_instance_enable and not isinstance(sub_instance_enable, str):
            raise TypeError("Expected argument 'sub_instance_enable' to be a str")
        pulumi.set(__self__, "sub_instance_enable", sub_instance_enable)
        if sub_instances and not isinstance(sub_instances, list):
            raise TypeError("Expected argument 'sub_instances' to be a list")
        pulumi.set(__self__, "sub_instances", sub_instances)
        if support_cold_node and not isinstance(support_cold_node, bool):
            raise TypeError("Expected argument 'support_cold_node' to be a bool")
        pulumi.set(__self__, "support_cold_node", support_cold_node)
        if total_nodes and not isinstance(total_nodes, int):
            raise TypeError("Expected argument 'total_nodes' to be a int")
        pulumi.set(__self__, "total_nodes", total_nodes)
        if transfer_info and not isinstance(transfer_info, dict):
            raise TypeError("Expected argument 'transfer_info' to be a dict")
        pulumi.set(__self__, "transfer_info", transfer_info)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="cerebroEnabled")
    def cerebro_enabled(self) -> builtins.bool:
        """
        是否开启 cerebro。true：开启 cerebrofalse：不开启 cerebro
        """
        return pulumi.get(self, "cerebro_enabled")

    @property
    @pulumi.getter(name="cerebroPrivateDomain")
    def cerebro_private_domain(self) -> builtins.str:
        """
        cerebro 私网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头
        """
        return pulumi.get(self, "cerebro_private_domain")

    @property
    @pulumi.getter(name="cerebroPublicDomain")
    def cerebro_public_domain(self) -> builtins.str:
        """
        erebro 公网访问地址。说明Cerebro 和 Kibana 共享域名。如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "cerebro_public_domain")

    @property
    @pulumi.getter(name="chargeEnabled")
    def charge_enabled(self) -> builtins.bool:
        """
        实例是否开启了计费。取值说明如下：true：已开启计费false：未开启计费
        """
        return pulumi.get(self, "charge_enabled")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        实例所属集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="enableEsPrivateDomainPublic")
    def enable_es_private_domain_public(self) -> builtins.bool:
        """
        实例是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_es_private_domain_public")

    @property
    @pulumi.getter(name="enableEsPrivateNetwork")
    def enable_es_private_network(self) -> builtins.bool:
        """
        实例是否开启了私网访问。true：默认值，开启私网访问false：未开启私网访问
        """
        return pulumi.get(self, "enable_es_private_network")

    @property
    @pulumi.getter(name="enableEsPublicNetwork")
    def enable_es_public_network(self) -> builtins.bool:
        """
        实例是否开启了公网访问。true：已开启公网访问false：未开启公网访问
        """
        return pulumi.get(self, "enable_es_public_network")

    @property
    @pulumi.getter(name="enableKibanaPrivateDomainPublic")
    def enable_kibana_private_domain_public(self) -> builtins.bool:
        """
        Kibana 是否开启私网地址公网解析。true：已开启私网地址公网解析false：未开启私网地址公网解析
        """
        return pulumi.get(self, "enable_kibana_private_domain_public")

    @property
    @pulumi.getter(name="enableKibanaPrivateNetwork")
    def enable_kibana_private_network(self) -> builtins.bool:
        """
        Kibana 是否开启私网访问。true：默认值，已开启私网访问 false：未开启Kibana私网访问
        """
        return pulumi.get(self, "enable_kibana_private_network")

    @property
    @pulumi.getter(name="enableKibanaPublicNetwork")
    def enable_kibana_public_network(self) -> builtins.bool:
        """
        Kibana 是否开启了公网访问。true：已开启公网访问 false：未开启公网访问
        """
        return pulumi.get(self, "enable_kibana_public_network")

    @property
    @pulumi.getter(name="esEip")
    def es_eip(self) -> builtins.str:
        """
        实例所绑定的 EIP。
        """
        return pulumi.get(self, "es_eip")

    @property
    @pulumi.getter(name="esEipId")
    def es_eip_id(self) -> builtins.str:
        """
        实例所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "es_eip_id")

    @property
    @pulumi.getter(name="esPrivateEndpoint")
    def es_private_endpoint(self) -> builtins.str:
        """
        实例私网访问地址。
        """
        return pulumi.get(self, "es_private_endpoint")

    @property
    @pulumi.getter(name="esPrivateIpAllowList")
    def es_private_ip_allow_list(self) -> builtins.str:
        """
        实例私网地址访问白名单。同 ESPrivateIpWhitelist
        """
        return pulumi.get(self, "es_private_ip_allow_list")

    @property
    @pulumi.getter(name="esPrivateIpWhitelist")
    def es_private_ip_whitelist(self) -> builtins.str:
        """
        实例私网地址访问白名单。
        """
        return pulumi.get(self, "es_private_ip_whitelist")

    @property
    @pulumi.getter(name="esPubBandwidth")
    def es_pub_bandwidth(self) -> builtins.int:
        """
        ES公网带宽，单位:Mbps。
        """
        return pulumi.get(self, "es_pub_bandwidth")

    @property
    @pulumi.getter(name="esPublicEndpoint")
    def es_public_endpoint(self) -> builtins.str:
        """
        实例公网访问地址。
        """
        return pulumi.get(self, "es_public_endpoint")

    @property
    @pulumi.getter(name="esPublicIpAllowList")
    def es_public_ip_allow_list(self) -> builtins.str:
        """
        实例公网地址访问白名单。同 ESPublicIpWhitelist
        """
        return pulumi.get(self, "es_public_ip_allow_list")

    @property
    @pulumi.getter(name="esPublicIpWhitelist")
    def es_public_ip_whitelist(self) -> builtins.str:
        """
        实例公网地址访问白名单。
        """
        return pulumi.get(self, "es_public_ip_whitelist")

    @property
    @pulumi.getter(name="expireDate")
    def expire_date(self) -> builtins.str:
        """
        包年包月实例的付费过期时间。
        """
        return pulumi.get(self, "expire_date")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceConfiguration")
    def instance_configuration(self) -> 'outputs.GetInstanceInstanceConfigurationResult':
        """
        实例配置详情信息。
        """
        return pulumi.get(self, "instance_configuration")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="kibanaConfig")
    def kibana_config(self) -> 'outputs.GetInstanceKibanaConfigResult':
        """
        Kibana 参数配置。
        """
        return pulumi.get(self, "kibana_config")

    @property
    @pulumi.getter(name="kibanaEip")
    def kibana_eip(self) -> builtins.str:
        """
        Kibana 所绑定的 EIP。
        """
        return pulumi.get(self, "kibana_eip")

    @property
    @pulumi.getter(name="kibanaEipId")
    def kibana_eip_id(self) -> builtins.str:
        """
        Kibana 所绑定的 EIP 的 ID。
        """
        return pulumi.get(self, "kibana_eip_id")

    @property
    @pulumi.getter(name="kibanaPrivateDomain")
    def kibana_private_domain(self) -> builtins.str:
        """
        Kibana 私网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_private_domain")

    @property
    @pulumi.getter(name="kibanaPrivateIpAllowList")
    def kibana_private_ip_allow_list(self) -> builtins.str:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPrivateIpWhitelist
        """
        return pulumi.get(self, "kibana_private_ip_allow_list")

    @property
    @pulumi.getter(name="kibanaPrivateIpWhitelist")
    def kibana_private_ip_whitelist(self) -> builtins.str:
        """
        Kibana 私网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单。
        """
        return pulumi.get(self, "kibana_private_ip_whitelist")

    @property
    @pulumi.getter(name="kibanaPubBandwidth")
    def kibana_pub_bandwidth(self) -> builtins.int:
        """
        Kibana公网带宽，单位: Mbps
        """
        return pulumi.get(self, "kibana_pub_bandwidth")

    @property
    @pulumi.getter(name="kibanaPublicDomain")
    def kibana_public_domain(self) -> builtins.str:
        """
        Kibana 公网访问地址。说明如果是历史实例，访问地址有可能是http(s)://kibana-***开头。
        """
        return pulumi.get(self, "kibana_public_domain")

    @property
    @pulumi.getter(name="kibanaPublicIpAllowList")
    def kibana_public_ip_allow_list(self) -> builtins.str:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。同 KibanaPublicIpWhitelist
        """
        return pulumi.get(self, "kibana_public_ip_allow_list")

    @property
    @pulumi.getter(name="kibanaPublicIpWhitelist")
    def kibana_public_ip_whitelist(self) -> builtins.str:
        """
        Kibana 公网白名单。只有添加到白名单中的 IP 地址才可以访问可视化工具。说明Cerebro 和 Kibana 共用一套白名单
        """
        return pulumi.get(self, "kibana_public_ip_whitelist")

    @property
    @pulumi.getter(name="mainZoneId")
    def main_zone_id(self) -> builtins.str:
        """
        主可用区
        """
        return pulumi.get(self, "main_zone_id")

    @property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> Sequence[builtins.str]:
        """
        实例的可维护日期。
        """
        return pulumi.get(self, "maintenance_days")

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> builtins.str:
        """
        实例的可维护时间段。
        """
        return pulumi.get(self, "maintenance_time")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        实例当前状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subInstanceEnable")
    def sub_instance_enable(self) -> builtins.str:
        """
        子实例开启情况。
        """
        return pulumi.get(self, "sub_instance_enable")

    @property
    @pulumi.getter(name="subInstances")
    def sub_instances(self) -> Sequence['outputs.GetInstanceSubInstanceResult']:
        """
        企业级 SQL 分析实例配置信息。
        """
        return pulumi.get(self, "sub_instances")

    @property
    @pulumi.getter(name="supportColdNode")
    def support_cold_node(self) -> builtins.bool:
        """
        是否支持冷节点。
        """
        return pulumi.get(self, "support_cold_node")

    @property
    @pulumi.getter(name="totalNodes")
    def total_nodes(self) -> builtins.int:
        """
        实例的总节点数。
        """
        return pulumi.get(self, "total_nodes")

    @property
    @pulumi.getter(name="transferInfo")
    def transfer_info(self) -> 'outputs.GetInstanceTransferInfoResult':
        """
        数据迁移任务信息。
        """
        return pulumi.get(self, "transfer_info")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        实例所有者的用户 ID。
        """
        return pulumi.get(self, "user_id")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            cerebro_enabled=self.cerebro_enabled,
            cerebro_private_domain=self.cerebro_private_domain,
            cerebro_public_domain=self.cerebro_public_domain,
            charge_enabled=self.charge_enabled,
            cluster_id=self.cluster_id,
            create_time=self.create_time,
            enable_es_private_domain_public=self.enable_es_private_domain_public,
            enable_es_private_network=self.enable_es_private_network,
            enable_es_public_network=self.enable_es_public_network,
            enable_kibana_private_domain_public=self.enable_kibana_private_domain_public,
            enable_kibana_private_network=self.enable_kibana_private_network,
            enable_kibana_public_network=self.enable_kibana_public_network,
            es_eip=self.es_eip,
            es_eip_id=self.es_eip_id,
            es_private_endpoint=self.es_private_endpoint,
            es_private_ip_allow_list=self.es_private_ip_allow_list,
            es_private_ip_whitelist=self.es_private_ip_whitelist,
            es_pub_bandwidth=self.es_pub_bandwidth,
            es_public_endpoint=self.es_public_endpoint,
            es_public_ip_allow_list=self.es_public_ip_allow_list,
            es_public_ip_whitelist=self.es_public_ip_whitelist,
            expire_date=self.expire_date,
            id=self.id,
            instance_configuration=self.instance_configuration,
            instance_id=self.instance_id,
            kibana_config=self.kibana_config,
            kibana_eip=self.kibana_eip,
            kibana_eip_id=self.kibana_eip_id,
            kibana_private_domain=self.kibana_private_domain,
            kibana_private_ip_allow_list=self.kibana_private_ip_allow_list,
            kibana_private_ip_whitelist=self.kibana_private_ip_whitelist,
            kibana_pub_bandwidth=self.kibana_pub_bandwidth,
            kibana_public_domain=self.kibana_public_domain,
            kibana_public_ip_allow_list=self.kibana_public_ip_allow_list,
            kibana_public_ip_whitelist=self.kibana_public_ip_whitelist,
            main_zone_id=self.main_zone_id,
            maintenance_days=self.maintenance_days,
            maintenance_time=self.maintenance_time,
            status=self.status,
            sub_instance_enable=self.sub_instance_enable,
            sub_instances=self.sub_instances,
            support_cold_node=self.support_cold_node,
            total_nodes=self.total_nodes,
            transfer_info=self.transfer_info,
            user_id=self.user_id)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::ESCloud::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:escloud/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        cerebro_enabled=pulumi.get(__ret__, 'cerebro_enabled'),
        cerebro_private_domain=pulumi.get(__ret__, 'cerebro_private_domain'),
        cerebro_public_domain=pulumi.get(__ret__, 'cerebro_public_domain'),
        charge_enabled=pulumi.get(__ret__, 'charge_enabled'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        create_time=pulumi.get(__ret__, 'create_time'),
        enable_es_private_domain_public=pulumi.get(__ret__, 'enable_es_private_domain_public'),
        enable_es_private_network=pulumi.get(__ret__, 'enable_es_private_network'),
        enable_es_public_network=pulumi.get(__ret__, 'enable_es_public_network'),
        enable_kibana_private_domain_public=pulumi.get(__ret__, 'enable_kibana_private_domain_public'),
        enable_kibana_private_network=pulumi.get(__ret__, 'enable_kibana_private_network'),
        enable_kibana_public_network=pulumi.get(__ret__, 'enable_kibana_public_network'),
        es_eip=pulumi.get(__ret__, 'es_eip'),
        es_eip_id=pulumi.get(__ret__, 'es_eip_id'),
        es_private_endpoint=pulumi.get(__ret__, 'es_private_endpoint'),
        es_private_ip_allow_list=pulumi.get(__ret__, 'es_private_ip_allow_list'),
        es_private_ip_whitelist=pulumi.get(__ret__, 'es_private_ip_whitelist'),
        es_pub_bandwidth=pulumi.get(__ret__, 'es_pub_bandwidth'),
        es_public_endpoint=pulumi.get(__ret__, 'es_public_endpoint'),
        es_public_ip_allow_list=pulumi.get(__ret__, 'es_public_ip_allow_list'),
        es_public_ip_whitelist=pulumi.get(__ret__, 'es_public_ip_whitelist'),
        expire_date=pulumi.get(__ret__, 'expire_date'),
        id=pulumi.get(__ret__, 'id'),
        instance_configuration=pulumi.get(__ret__, 'instance_configuration'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        kibana_config=pulumi.get(__ret__, 'kibana_config'),
        kibana_eip=pulumi.get(__ret__, 'kibana_eip'),
        kibana_eip_id=pulumi.get(__ret__, 'kibana_eip_id'),
        kibana_private_domain=pulumi.get(__ret__, 'kibana_private_domain'),
        kibana_private_ip_allow_list=pulumi.get(__ret__, 'kibana_private_ip_allow_list'),
        kibana_private_ip_whitelist=pulumi.get(__ret__, 'kibana_private_ip_whitelist'),
        kibana_pub_bandwidth=pulumi.get(__ret__, 'kibana_pub_bandwidth'),
        kibana_public_domain=pulumi.get(__ret__, 'kibana_public_domain'),
        kibana_public_ip_allow_list=pulumi.get(__ret__, 'kibana_public_ip_allow_list'),
        kibana_public_ip_whitelist=pulumi.get(__ret__, 'kibana_public_ip_whitelist'),
        main_zone_id=pulumi.get(__ret__, 'main_zone_id'),
        maintenance_days=pulumi.get(__ret__, 'maintenance_days'),
        maintenance_time=pulumi.get(__ret__, 'maintenance_time'),
        status=pulumi.get(__ret__, 'status'),
        sub_instance_enable=pulumi.get(__ret__, 'sub_instance_enable'),
        sub_instances=pulumi.get(__ret__, 'sub_instances'),
        support_cold_node=pulumi.get(__ret__, 'support_cold_node'),
        total_nodes=pulumi.get(__ret__, 'total_nodes'),
        transfer_info=pulumi.get(__ret__, 'transfer_info'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::ESCloud::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:escloud/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        cerebro_enabled=pulumi.get(__response__, 'cerebro_enabled'),
        cerebro_private_domain=pulumi.get(__response__, 'cerebro_private_domain'),
        cerebro_public_domain=pulumi.get(__response__, 'cerebro_public_domain'),
        charge_enabled=pulumi.get(__response__, 'charge_enabled'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        create_time=pulumi.get(__response__, 'create_time'),
        enable_es_private_domain_public=pulumi.get(__response__, 'enable_es_private_domain_public'),
        enable_es_private_network=pulumi.get(__response__, 'enable_es_private_network'),
        enable_es_public_network=pulumi.get(__response__, 'enable_es_public_network'),
        enable_kibana_private_domain_public=pulumi.get(__response__, 'enable_kibana_private_domain_public'),
        enable_kibana_private_network=pulumi.get(__response__, 'enable_kibana_private_network'),
        enable_kibana_public_network=pulumi.get(__response__, 'enable_kibana_public_network'),
        es_eip=pulumi.get(__response__, 'es_eip'),
        es_eip_id=pulumi.get(__response__, 'es_eip_id'),
        es_private_endpoint=pulumi.get(__response__, 'es_private_endpoint'),
        es_private_ip_allow_list=pulumi.get(__response__, 'es_private_ip_allow_list'),
        es_private_ip_whitelist=pulumi.get(__response__, 'es_private_ip_whitelist'),
        es_pub_bandwidth=pulumi.get(__response__, 'es_pub_bandwidth'),
        es_public_endpoint=pulumi.get(__response__, 'es_public_endpoint'),
        es_public_ip_allow_list=pulumi.get(__response__, 'es_public_ip_allow_list'),
        es_public_ip_whitelist=pulumi.get(__response__, 'es_public_ip_whitelist'),
        expire_date=pulumi.get(__response__, 'expire_date'),
        id=pulumi.get(__response__, 'id'),
        instance_configuration=pulumi.get(__response__, 'instance_configuration'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        kibana_config=pulumi.get(__response__, 'kibana_config'),
        kibana_eip=pulumi.get(__response__, 'kibana_eip'),
        kibana_eip_id=pulumi.get(__response__, 'kibana_eip_id'),
        kibana_private_domain=pulumi.get(__response__, 'kibana_private_domain'),
        kibana_private_ip_allow_list=pulumi.get(__response__, 'kibana_private_ip_allow_list'),
        kibana_private_ip_whitelist=pulumi.get(__response__, 'kibana_private_ip_whitelist'),
        kibana_pub_bandwidth=pulumi.get(__response__, 'kibana_pub_bandwidth'),
        kibana_public_domain=pulumi.get(__response__, 'kibana_public_domain'),
        kibana_public_ip_allow_list=pulumi.get(__response__, 'kibana_public_ip_allow_list'),
        kibana_public_ip_whitelist=pulumi.get(__response__, 'kibana_public_ip_whitelist'),
        main_zone_id=pulumi.get(__response__, 'main_zone_id'),
        maintenance_days=pulumi.get(__response__, 'maintenance_days'),
        maintenance_time=pulumi.get(__response__, 'maintenance_time'),
        status=pulumi.get(__response__, 'status'),
        sub_instance_enable=pulumi.get(__response__, 'sub_instance_enable'),
        sub_instances=pulumi.get(__response__, 'sub_instances'),
        support_cold_node=pulumi.get(__response__, 'support_cold_node'),
        total_nodes=pulumi.get(__response__, 'total_nodes'),
        transfer_info=pulumi.get(__response__, 'transfer_info'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSubnetResult',
    'AwaitableGetSubnetResult',
    'get_subnet',
    'get_subnet_output',
]

@pulumi.output_type
class GetSubnetResult:
    """
    A collection of values returned by getSubnet.
    """
    def __init__(__self__, account_id=None, available_ip_address_count=None, cidr_block=None, created_time=None, description=None, enable_ipv6=None, id=None, ipv6_cidr_block=None, is_default=None, network_acl_id=None, project_name=None, read_ipv6_cidr_block=None, route_table=None, status=None, subnet_id=None, subnet_name=None, tags=None, total_ipv4_count=None, updated_time=None, vpc_id=None, zone_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if available_ip_address_count and not isinstance(available_ip_address_count, int):
            raise TypeError("Expected argument 'available_ip_address_count' to be a int")
        pulumi.set(__self__, "available_ip_address_count", available_ip_address_count)
        if cidr_block and not isinstance(cidr_block, str):
            raise TypeError("Expected argument 'cidr_block' to be a str")
        pulumi.set(__self__, "cidr_block", cidr_block)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_ipv6 and not isinstance(enable_ipv6, bool):
            raise TypeError("Expected argument 'enable_ipv6' to be a bool")
        pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv6_cidr_block and not isinstance(ipv6_cidr_block, str):
            raise TypeError("Expected argument 'ipv6_cidr_block' to be a str")
        pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if network_acl_id and not isinstance(network_acl_id, str):
            raise TypeError("Expected argument 'network_acl_id' to be a str")
        pulumi.set(__self__, "network_acl_id", network_acl_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if read_ipv6_cidr_block and not isinstance(read_ipv6_cidr_block, str):
            raise TypeError("Expected argument 'read_ipv6_cidr_block' to be a str")
        pulumi.set(__self__, "read_ipv6_cidr_block", read_ipv6_cidr_block)
        if route_table and not isinstance(route_table, dict):
            raise TypeError("Expected argument 'route_table' to be a dict")
        pulumi.set(__self__, "route_table", route_table)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if subnet_name and not isinstance(subnet_name, str):
            raise TypeError("Expected argument 'subnet_name' to be a str")
        pulumi.set(__self__, "subnet_name", subnet_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if total_ipv4_count and not isinstance(total_ipv4_count, int):
            raise TypeError("Expected argument 'total_ipv4_count' to be a int")
        pulumi.set(__self__, "total_ipv4_count", total_ipv4_count)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        子网所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="availableIpAddressCount")
    def available_ip_address_count(self) -> builtins.int:
        """
        子网中可用的IP地址数量。
        """
        return pulumi.get(self, "available_ip_address_count")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> builtins.str:
        """
        子网的IPv4网段。
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        子网的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> builtins.bool:
        """
        开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> builtins.str:
        """
        子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> builtins.bool:
        """
        该子网是否为默认子网。1、true：默认子网，表示该子网是创建ECS实例时系统自动创建的子网。2、false：非默认子网，表示该子网是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> builtins.str:
        """
        子网关联的网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        子网所在VPC实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="readIpv6CidrBlock")
    def read_ipv6_cidr_block(self) -> builtins.str:
        """
        只读字段，子网IPv6网段。
        """
        return pulumi.get(self, "read_ipv6_cidr_block")

    @property
    @pulumi.getter(name="routeTable")
    def route_table(self) -> 'outputs.GetSubnetRouteTableResult':
        """
        路由表信息。
        """
        return pulumi.get(self, "route_table")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        子网的状态。1、Pending：表示配置中。2、Available：表示可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        待修改信息的子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> builtins.str:
        """
        子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        """
        return pulumi.get(self, "subnet_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetSubnetTagResult']:
        """
        子网的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalIpv4Count")
    def total_ipv4_count(self) -> builtins.int:
        """
        子网下可用IP总数。
        """
        return pulumi.get(self, "total_ipv4_count")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        子网的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        子网所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetSubnetResult(GetSubnetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSubnetResult(
            account_id=self.account_id,
            available_ip_address_count=self.available_ip_address_count,
            cidr_block=self.cidr_block,
            created_time=self.created_time,
            description=self.description,
            enable_ipv6=self.enable_ipv6,
            id=self.id,
            ipv6_cidr_block=self.ipv6_cidr_block,
            is_default=self.is_default,
            network_acl_id=self.network_acl_id,
            project_name=self.project_name,
            read_ipv6_cidr_block=self.read_ipv6_cidr_block,
            route_table=self.route_table,
            status=self.status,
            subnet_id=self.subnet_id,
            subnet_name=self.subnet_name,
            tags=self.tags,
            total_ipv4_count=self.total_ipv4_count,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id,
            zone_id=self.zone_id)


def get_subnet(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSubnetResult:
    """
    Data Source schema for Byteplus::VPC::Subnet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getSubnet:getSubnet', __args__, opts=opts, typ=GetSubnetResult).value

    return AwaitableGetSubnetResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        available_ip_address_count=pulumi.get(__ret__, 'available_ip_address_count'),
        cidr_block=pulumi.get(__ret__, 'cidr_block'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enable_ipv6=pulumi.get(__ret__, 'enable_ipv6'),
        id=pulumi.get(__ret__, 'id'),
        ipv6_cidr_block=pulumi.get(__ret__, 'ipv6_cidr_block'),
        is_default=pulumi.get(__ret__, 'is_default'),
        network_acl_id=pulumi.get(__ret__, 'network_acl_id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        read_ipv6_cidr_block=pulumi.get(__ret__, 'read_ipv6_cidr_block'),
        route_table=pulumi.get(__ret__, 'route_table'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        subnet_name=pulumi.get(__ret__, 'subnet_name'),
        tags=pulumi.get(__ret__, 'tags'),
        total_ipv4_count=pulumi.get(__ret__, 'total_ipv4_count'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_subnet_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSubnetResult]:
    """
    Data Source schema for Byteplus::VPC::Subnet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getSubnet:getSubnet', __args__, opts=opts, typ=GetSubnetResult)
    return __ret__.apply(lambda __response__: GetSubnetResult(
        account_id=pulumi.get(__response__, 'account_id'),
        available_ip_address_count=pulumi.get(__response__, 'available_ip_address_count'),
        cidr_block=pulumi.get(__response__, 'cidr_block'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enable_ipv6=pulumi.get(__response__, 'enable_ipv6'),
        id=pulumi.get(__response__, 'id'),
        ipv6_cidr_block=pulumi.get(__response__, 'ipv6_cidr_block'),
        is_default=pulumi.get(__response__, 'is_default'),
        network_acl_id=pulumi.get(__response__, 'network_acl_id'),
        project_name=pulumi.get(__response__, 'project_name'),
        read_ipv6_cidr_block=pulumi.get(__response__, 'read_ipv6_cidr_block'),
        route_table=pulumi.get(__response__, 'route_table'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        subnet_name=pulumi.get(__response__, 'subnet_name'),
        tags=pulumi.get(__response__, 'tags'),
        total_ipv4_count=pulumi.get(__response__, 'total_ipv4_count'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_id=pulumi.get(__response__, 'zone_id')))
